@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2007, 2010 Free Software Foundation, Inc.
  * Author: Ludovic Courts, Timo Schulz
  *
  * This file is part of GnuTLS.
@@ -193,7 +193,7 @@ doit (void)
   gnutls_datum_t data;
   int ret;
 
-  ret = global_init ();
+  ret = gnutls_global_init ();
   if (ret < 0)
     fail ("init %d\n", ret);
 
